/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtWebKitWidgetsAPI_H
#define _QtWebKitWidgetsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QWebPage__ChooseMultipleFilesExtensionOption 0
#define sipName_QWebPage__ChooseMultipleFilesExtensionOption &sipStrings_QtWebKitWidgets[0]
#define sipNameNr_QWebPage__ChooseMultipleFilesExtensionReturn 45
#define sipName_QWebPage__ChooseMultipleFilesExtensionReturn &sipStrings_QtWebKitWidgets[45]
#define sipNameNr_ChooseMultipleFilesExtensionOption 10
#define sipName_ChooseMultipleFilesExtensionOption &sipStrings_QtWebKitWidgets[10]
#define sipNameNr_ChooseMultipleFilesExtensionReturn 55
#define sipName_ChooseMultipleFilesExtensionReturn &sipStrings_QtWebKitWidgets[55]
#define sipNameNr_QWebPage__ErrorPageExtensionOption 90
#define sipName_QWebPage__ErrorPageExtensionOption &sipStrings_QtWebKitWidgets[90]
#define sipNameNr_QWebPage__ErrorPageExtensionReturn 125
#define sipName_QWebPage__ErrorPageExtensionReturn &sipStrings_QtWebKitWidgets[125]
#define sipNameNr_statusBarVisibilityChangeRequested 160
#define sipName_statusBarVisibilityChangeRequested &sipStrings_QtWebKitWidgets[160]
#define sipNameNr_TreatMedialCapitalAsWordBeginning 195
#define sipName_TreatMedialCapitalAsWordBeginning &sipStrings_QtWebKitWidgets[195]
#define sipNameNr_featurePermissionRequestCanceled 229
#define sipName_featurePermissionRequestCanceled &sipStrings_QtWebKitWidgets[229]
#define sipNameNr_menuBarVisibilityChangeRequested 262
#define sipName_menuBarVisibilityChangeRequested &sipStrings_QtWebKitWidgets[262]
#define sipNameNr_toolBarVisibilityChangeRequested 295
#define sipName_toolBarVisibilityChangeRequested &sipStrings_QtWebKitWidgets[295]
#define sipNameNr_QWebPage__LinkDelegationPolicy 328
#define sipName_QWebPage__LinkDelegationPolicy &sipStrings_QtWebKitWidgets[328]
#define sipNameNr_updatePositionDependentActions 359
#define sipName_updatePositionDependentActions &sipStrings_QtWebKitWidgets[359]
#define sipNameNr_NavigationTypeFormResubmitted 390
#define sipName_NavigationTypeFormResubmitted &sipStrings_QtWebKitWidgets[390]
#define sipNameNr_applicationCacheQuotaExceeded 420
#define sipName_applicationCacheQuotaExceeded &sipStrings_QtWebKitWidgets[420]
#define sipNameNr_javaScriptWindowObjectCleared 450
#define sipName_javaScriptWindowObjectCleared &sipStrings_QtWebKitWidgets[450]
#define sipNameNr_ChooseMultipleFilesExtension 480
#define sipName_ChooseMultipleFilesExtension &sipStrings_QtWebKitWidgets[480]
#define sipNameNr_QWebPage__ViewportAttributes 509
#define sipName_QWebPage__ViewportAttributes &sipStrings_QtWebKitWidgets[509]
#define sipNameNr_setForwardUnsupportedContent 538
#define sipName_setForwardUnsupportedContent &sipStrings_QtWebKitWidgets[538]
#define sipNameNr_NavigationTypeBackOrForward 567
#define sipName_NavigationTypeBackOrForward &sipStrings_QtWebKitWidgets[567]
#define sipNameNr_NavigationTypeFormSubmitted 595
#define sipName_NavigationTypeFormSubmitted &sipStrings_QtWebKitWidgets[595]
#define sipNameNr_SetTextDirectionLeftToRight 623
#define sipName_SetTextDirectionLeftToRight &sipStrings_QtWebKitWidgets[623]
#define sipNameNr_SetTextDirectionRightToLeft 651
#define sipName_SetTextDirectionRightToLeft &sipStrings_QtWebKitWidgets[651]
#define sipNameNr_addToJavaScriptWindowObject 679
#define sipName_addToJavaScriptWindowObject &sipStrings_QtWebKitWidgets[679]
#define sipNameNr_setActualVisibleContentRect 707
#define sipName_setActualVisibleContentRect &sipStrings_QtWebKitWidgets[707]
#define sipNameNr_735 735
#define sipName_735 &sipStrings_QtWebKitWidgets[735]
#define sipNameNr_QWebPage__PermissionPolicy 762
#define sipName_QWebPage__PermissionPolicy &sipStrings_QtWebKitWidgets[762]
#define sipNameNr_featurePermissionRequested 789
#define sipName_featurePermissionRequested &sipStrings_QtWebKitWidgets[789]
#define sipNameNr_restoreFrameStateRequested 816
#define sipName_restoreFrameStateRequested &sipStrings_QtWebKitWidgets[816]
#define sipNameNr_setTiledBackingStoreFrozen 843
#define sipName_setTiledBackingStoreFrozen &sipStrings_QtWebKitWidgets[843]
#define sipNameNr_NavigationTypeLinkClicked 870
#define sipName_NavigationTypeLinkClicked &sipStrings_QtWebKitWidgets[870]
#define sipNameNr_QWebFrame__ValueOwnership 896
#define sipName_QWebFrame__ValueOwnership &sipStrings_QtWebKitWidgets[896]
#define sipNameNr_QWebPage__ExtensionOption 922
#define sipName_QWebPage__ExtensionOption &sipStrings_QtWebKitWidgets[922]
#define sipNameNr_QWebPage__ExtensionReturn 948
#define sipName_QWebPage__ExtensionReturn &sipStrings_QtWebKitWidgets[948]
#define sipNameNr_QWebPage__VisibilityState 974
#define sipName_QWebPage__VisibilityState &sipStrings_QtWebKitWidgets[974]
#define sipNameNr_createStandardContextMenu 1000
#define sipName_createStandardContextMenu &sipStrings_QtWebKitWidgets[1000]
#define sipNameNr_forwardUnsupportedContent 1026
#define sipName_forwardUnsupportedContent &sipStrings_QtWebKitWidgets[1026]
#define sipNameNr_isTiledBackingStoreFrozen 1052
#define sipName_isTiledBackingStoreFrozen &sipStrings_QtWebKitWidgets[1052]
#define sipNameNr_shouldInterruptJavaScript 1078
#define sipName_shouldInterruptJavaScript &sipStrings_QtWebKitWidgets[1078]
#define sipNameNr_viewportAttributesForSize 1104
#define sipName_viewportAttributesForSize &sipStrings_QtWebKitWidgets[1104]
#define sipNameNr_ErrorPageExtensionOption 100
#define sipName_ErrorPageExtensionOption &sipStrings_QtWebKitWidgets[100]
#define sipNameNr_ErrorPageExtensionReturn 135
#define sipName_ErrorPageExtensionReturn &sipStrings_QtWebKitWidgets[135]
#define sipNameNr_FindAtWordBeginningsOnly 1130
#define sipName_FindAtWordBeginningsOnly &sipStrings_QtWebKitWidgets[1130]
#define sipNameNr_InsertParagraphSeparator 1155
#define sipName_InsertParagraphSeparator &sipStrings_QtWebKitWidgets[1155]
#define sipNameNr_QWebPage__NavigationType 1180
#define sipName_QWebPage__NavigationType &sipStrings_QtWebKitWidgets[1180]
#define sipNameNr_StopScheduledPageRefresh 1205
#define sipName_StopScheduledPageRefresh &sipStrings_QtWebKitWidgets[1205]
#define sipNameNr_VisibilityStatePrerender 1230
#define sipName_VisibilityStatePrerender &sipStrings_QtWebKitWidgets[1230]
#define sipNameNr_javaScriptConsoleMessage 1255
#define sipName_javaScriptConsoleMessage &sipStrings_QtWebKitWidgets[1255]
#define sipNameNr_setPreferredContentsSize 1280
#define sipName_setPreferredContentsSize &sipStrings_QtWebKitWidgets[1280]
#define sipNameNr_CopyImageUrlToClipboard 1305
#define sipName_CopyImageUrlToClipboard &sipStrings_QtWebKitWidgets[1305]
#define sipNameNr_CopyMediaUrlToClipboard 1329
#define sipName_CopyMediaUrlToClipboard &sipStrings_QtWebKitWidgets[1329]
#define sipNameNr_FindWrapsAroundDocument 1353
#define sipName_FindWrapsAroundDocument &sipStrings_QtWebKitWidgets[1353]
#define sipNameNr_HighlightAllOccurrences 1377
#define sipName_HighlightAllOccurrences &sipStrings_QtWebKitWidgets[1377]
#define sipNameNr_PermissionGrantedByUser 1401
#define sipName_PermissionGrantedByUser &sipStrings_QtWebKitWidgets[1401]
#define sipNameNr_QWebFrame__RenderLayers 1425
#define sipName_QWebFrame__RenderLayers &sipStrings_QtWebKitWidgets[1425]
#define sipNameNr_QWebPage__WebWindowType 1449
#define sipName_QWebPage__WebWindowType &sipStrings_QtWebKitWidgets[1449]
#define sipNameNr_SetTextDirectionDefault 1473
#define sipName_SetTextDirectionDefault &sipStrings_QtWebKitWidgets[1473]
#define sipNameNr_VisibilityStateUnloaded 1497
#define sipName_VisibilityStateUnloaded &sipStrings_QtWebKitWidgets[1497]
#define sipNameNr_acceptNavigationRequest 1521
#define sipName_acceptNavigationRequest &sipStrings_QtWebKitWidgets[1521]
#define sipNameNr_geometryChangeRequested 1545
#define sipName_geometryChangeRequested &sipStrings_QtWebKitWidgets[1545]
#define sipNameNr_saveFrameStateRequested 1569
#define sipName_saveFrameStateRequested &sipStrings_QtWebKitWidgets[1569]
#define sipNameNr_setLinkDelegationPolicy 1593
#define sipName_setLinkDelegationPolicy &sipStrings_QtWebKitWidgets[1593]
#define sipNameNr_setNetworkAccessManager 1617
#define sipName_setNetworkAccessManager &sipStrings_QtWebKitWidgets[1617]
#define sipNameNr_swallowContextMenuEvent 1641
#define sipName_swallowContextMenuEvent &sipStrings_QtWebKitWidgets[1641]
#define sipNameNr_viewportChangeRequested 1665
#define sipName_viewportChangeRequested &sipStrings_QtWebKitWidgets[1665]
#define sipNameNr_PermissionDeniedByUser 1689
#define sipName_PermissionDeniedByUser &sipStrings_QtWebKitWidgets[1689]
#define sipNameNr_QWebFrame__RenderLayer 1712
#define sipName_QWebFrame__RenderLayer &sipStrings_QtWebKitWidgets[1712]
#define sipNameNr_VisibilityStateVisible 1735
#define sipName_VisibilityStateVisible &sipStrings_QtWebKitWidgets[1735]
#define sipNameNr_initialLayoutCompleted 1758
#define sipName_initialLayoutCompleted &sipStrings_QtWebKitWidgets[1758]
#define sipNameNr_DelegateExternalLinks 1781
#define sipName_DelegateExternalLinks &sipStrings_QtWebKitWidgets[1781]
#define sipNameNr_FindBeginsInSelection 1803
#define sipName_FindBeginsInSelection &sipStrings_QtWebKitWidgets[1803]
#define sipNameNr_MoveToStartOfDocument 1825
#define sipName_MoveToStartOfDocument &sipStrings_QtWebKitWidgets[1825]
#define sipNameNr_PyQt5_QtWebKitWidgets 1847
#define sipName_PyQt5_QtWebKitWidgets &sipStrings_QtWebKitWidgets[1847]
#define sipNameNr_QWebPage__ErrorDomain 1869
#define sipName_QWebPage__ErrorDomain &sipStrings_QtWebKitWidgets[1869]
#define sipNameNr_SelectStartOfDocument 1891
#define sipName_SelectStartOfDocument &sipStrings_QtWebKitWidgets[1891]
#define sipNameNr_ToggleVideoFullscreen 1913
#define sipName_ToggleVideoFullscreen &sipStrings_QtWebKitWidgets[1913]
#define sipNameNr_VisibilityStateHidden 1935
#define sipName_VisibilityStateHidden &sipStrings_QtWebKitWidgets[1935]
#define sipNameNr_databaseQuotaExceeded 1957
#define sipName_databaseQuotaExceeded &sipStrings_QtWebKitWidgets[1957]
#define sipNameNr_enclosingBlockElement 1979
#define sipName_enclosingBlockElement &sipStrings_QtWebKitWidgets[1979]
#define sipNameNr_mouseDoubleClickEvent 2001
#define sipName_mouseDoubleClickEvent &sipStrings_QtWebKitWidgets[2001]
#define sipNameNr_preferredContentsSize 2023
#define sipName_preferredContentsSize &sipStrings_QtWebKitWidgets[2023]
#define sipNameNr_supportedContentTypes 2045
#define sipName_supportedContentTypes &sipStrings_QtWebKitWidgets[2045]
#define sipNameNr_CopyImageToClipboard 2067
#define sipName_CopyImageToClipboard &sipStrings_QtWebKitWidgets[2067]
#define sipNameNr_LinkDelegationPolicy 338
#define sipName_LinkDelegationPolicy &sipStrings_QtWebKitWidgets[338]
#define sipNameNr_NavigationTypeReload 2088
#define sipName_NavigationTypeReload &sipStrings_QtWebKitWidgets[2088]
#define sipNameNr_OpenFrameInNewWindow 2109
#define sipName_OpenFrameInNewWindow &sipStrings_QtWebKitWidgets[2109]
#define sipNameNr_OpenImageInNewWindow 2130
#define sipName_OpenImageInNewWindow &sipStrings_QtWebKitWidgets[2130]
#define sipNameNr_OpenLinkInThisWindow 2151
#define sipName_OpenLinkInThisWindow &sipStrings_QtWebKitWidgets[2151]
#define sipNameNr_ReloadAndBypassCache 2172
#define sipName_ReloadAndBypassCache &sipStrings_QtWebKitWidgets[2172]
#define sipNameNr_ToggleMediaPlayPause 2193
#define sipName_ToggleMediaPlayPause &sipStrings_QtWebKitWidgets[2193]
#define sipNameNr_linkDelegationPolicy 2214
#define sipName_linkDelegationPolicy &sipStrings_QtWebKitWidgets[2214]
#define sipNameNr_networkAccessManager 2235
#define sipName_networkAccessManager &sipStrings_QtWebKitWidgets[2235]
#define sipNameNr_setFeaturePermission 2256
#define sipName_setFeaturePermission &sipStrings_QtWebKitWidgets[2256]
#define sipNameNr_setResizesToContents 2277
#define sipName_setResizesToContents &sipStrings_QtWebKitWidgets[2277]
#define sipNameNr_windowCloseRequested 2298
#define sipName_windowCloseRequested &sipStrings_QtWebKitWidgets[2298]
#define sipNameNr_windowFrameSectionAt 2319
#define sipName_windowFrameSectionAt &sipStrings_QtWebKitWidgets[2319]
#define sipNameNr_CopyLinkToClipboard 2340
#define sipName_CopyLinkToClipboard &sipStrings_QtWebKitWidgets[2340]
#define sipNameNr_DownloadImageToDisk 2360
#define sipName_DownloadImageToDisk &sipStrings_QtWebKitWidgets[2360]
#define sipNameNr_DownloadMediaToDisk 2380
#define sipName_DownloadMediaToDisk &sipStrings_QtWebKitWidgets[2380]
#define sipNameNr_FindCaseSensitively 2400
#define sipName_FindCaseSensitively &sipStrings_QtWebKitWidgets[2400]
#define sipNameNr_InsertLineSeparator 2420
#define sipName_InsertLineSeparator &sipStrings_QtWebKitWidgets[2420]
#define sipNameNr_InsertUnorderedList 2440
#define sipName_InsertUnorderedList &sipStrings_QtWebKitWidgets[2440]
#define sipNameNr_MoveToEndOfDocument 2460
#define sipName_MoveToEndOfDocument &sipStrings_QtWebKitWidgets[2460]
#define sipNameNr_NavigationTypeOther 2480
#define sipName_NavigationTypeOther &sipStrings_QtWebKitWidgets[2480]
#define sipNameNr_OpenLinkInNewWindow 2500
#define sipName_OpenLinkInNewWindow &sipStrings_QtWebKitWidgets[2500]
#define sipNameNr_QWebPage__Extension 2520
#define sipName_QWebPage__Extension &sipStrings_QtWebKitWidgets[2520]
#define sipNameNr_QWebPage__FindFlags 2540
#define sipName_QWebPage__FindFlags &sipStrings_QtWebKitWidgets[2540]
#define sipNameNr_QWebPage__WebAction 2560
#define sipName_QWebPage__WebAction &sipStrings_QtWebKitWidgets[2560]
#define sipNameNr_SelectEndOfDocument 2580
#define sipName_SelectEndOfDocument &sipStrings_QtWebKitWidgets[2580]
#define sipNameNr_ToggleMediaControls 2600
#define sipName_ToggleMediaControls &sipStrings_QtWebKitWidgets[2600]
#define sipNameNr_ToggleStrikethrough 2620
#define sipName_ToggleStrikethrough &sipStrings_QtWebKitWidgets[2620]
#define sipNameNr_contentsSizeChanged 2640
#define sipName_contentsSizeChanged &sipStrings_QtWebKitWidgets[2640]
#define sipNameNr_supportsContentType 2660
#define sipName_supportsContentType &sipStrings_QtWebKitWidgets[2660]
#define sipNameNr_ungrabKeyboardEvent 2680
#define sipName_ungrabKeyboardEvent &sipStrings_QtWebKitWidgets[2680]
#define sipNameNr_DownloadLinkToDisk 2700
#define sipName_DownloadLinkToDisk &sipStrings_QtWebKitWidgets[2700]
#define sipNameNr_ErrorPageExtension 2719
#define sipName_ErrorPageExtension &sipStrings_QtWebKitWidgets[2719]
#define sipNameNr_MoveToPreviousChar 2738
#define sipName_MoveToPreviousChar &sipStrings_QtWebKitWidgets[2738]
#define sipNameNr_MoveToPreviousLine 2757
#define sipName_MoveToPreviousLine &sipStrings_QtWebKitWidgets[2757]
#define sipNameNr_MoveToPreviousWord 2776
#define sipName_MoveToPreviousWord &sipStrings_QtWebKitWidgets[2776]
#define sipNameNr_MoveToStartOfBlock 2795
#define sipName_MoveToStartOfBlock &sipStrings_QtWebKitWidgets[2795]
#define sipNameNr_PasteAndMatchStyle 2814
#define sipName_PasteAndMatchStyle &sipStrings_QtWebKitWidgets[2814]
#define sipNameNr_QWebPage__FindFlag 2833
#define sipName_QWebPage__FindFlag &sipStrings_QtWebKitWidgets[2833]
#define sipNameNr_SelectPreviousChar 2852
#define sipName_SelectPreviousChar &sipStrings_QtWebKitWidgets[2852]
#define sipNameNr_SelectPreviousLine 2871
#define sipName_SelectPreviousLine &sipStrings_QtWebKitWidgets[2871]
#define sipNameNr_SelectPreviousWord 2890
#define sipName_SelectPreviousWord &sipStrings_QtWebKitWidgets[2890]
#define sipNameNr_SelectStartOfBlock 2909
#define sipName_SelectStartOfBlock &sipStrings_QtWebKitWidgets[2909]
#define sipNameNr_ViewportAttributes 519
#define sipName_ViewportAttributes &sipStrings_QtWebKitWidgets[519]
#define sipNameNr_evaluateJavaScript 2928
#define sipName_evaluateJavaScript &sipStrings_QtWebKitWidgets[2928]
#define sipNameNr_focusNextPrevChild 2947
#define sipName_focusNextPrevChild &sipStrings_QtWebKitWidgets[2947]
#define sipNameNr_getContentsMargins 2966
#define sipName_getContentsMargins &sipStrings_QtWebKitWidgets[2966]
#define sipNameNr_initialScaleFactor 2985
#define sipName_initialScaleFactor &sipStrings_QtWebKitWidgets[2985]
#define sipNameNr_maximumScaleFactor 3004
#define sipName_maximumScaleFactor &sipStrings_QtWebKitWidgets[3004]
#define sipNameNr_minimumScaleFactor 3023
#define sipName_minimumScaleFactor &sipStrings_QtWebKitWidgets[3023]
#define sipNameNr_setContentEditable 3042
#define sipName_setContentEditable &sipStrings_QtWebKitWidgets[3042]
#define sipNameNr_setScrollBarPolicy 3061
#define sipName_setScrollBarPolicy &sipStrings_QtWebKitWidgets[3061]
#define sipNameNr_setVisibilityState 3080
#define sipName_setVisibilityState &sipStrings_QtWebKitWidgets[3080]
#define sipNameNr_suggestedFileNames 3099
#define sipName_suggestedFileNames &sipStrings_QtWebKitWidgets[3099]
#define sipNameNr_unsupportedContent 3118
#define sipName_unsupportedContent &sipStrings_QtWebKitWidgets[3118]
#define sipNameNr_DeleteStartOfWord 3137
#define sipName_DeleteStartOfWord &sipStrings_QtWebKitWidgets[3137]
#define sipNameNr_DontDelegateLinks 3155
#define sipName_DontDelegateLinks &sipStrings_QtWebKitWidgets[3155]
#define sipNameNr_InsertOrderedList 3173
#define sipName_InsertOrderedList &sipStrings_QtWebKitWidgets[3173]
#define sipNameNr_MoveToStartOfLine 3191
#define sipName_MoveToStartOfLine &sipStrings_QtWebKitWidgets[3191]
#define sipNameNr_PermissionUnknown 3209
#define sipName_PermissionUnknown &sipStrings_QtWebKitWidgets[3209]
#define sipNameNr_3227 3227
#define sipName_3227 &sipStrings_QtWebKitWidgets[3227]
#define sipNameNr_QWebHitTestResult 3245
#define sipName_QWebHitTestResult &sipStrings_QtWebKitWidgets[3245]
#define sipNameNr_QWebPage__Feature 3263
#define sipName_QWebPage__Feature &sipStrings_QtWebKitWidgets[3263]
#define sipNameNr_SelectStartOfLine 3281
#define sipName_SelectStartOfLine &sipStrings_QtWebKitWidgets[3281]
#define sipNameNr_ToggleSuperscript 3299
#define sipName_ToggleSuperscript &sipStrings_QtWebKitWidgets[3299]
#define sipNameNr_downloadRequested 3317
#define sipName_downloadRequested &sipStrings_QtWebKitWidgets[3317]
#define sipNameNr_grabKeyboardEvent 2682
#define sipName_grabKeyboardEvent &sipStrings_QtWebKitWidgets[2682]
#define sipNameNr_hasHeightForWidth 3335
#define sipName_hasHeightForWidth &sipStrings_QtWebKitWidgets[3335]
#define sipNameNr_isContentEditable 3353
#define sipName_isContentEditable &sipStrings_QtWebKitWidgets[3353]
#define sipNameNr_isContentSelected 3371
#define sipName_isContentSelected &sipStrings_QtWebKitWidgets[3371]
#define sipNameNr_javaScriptConfirm 3389
#define sipName_javaScriptConfirm &sipStrings_QtWebKitWidgets[3389]
#define sipNameNr_microFocusChanged 3407
#define sipName_microFocusChanged &sipStrings_QtWebKitWidgets[3407]
#define sipNameNr_mouseReleaseEvent 3425
#define sipName_mouseReleaseEvent &sipStrings_QtWebKitWidgets[3425]
#define sipNameNr_resizesToContents 3443
#define sipName_resizesToContents &sipStrings_QtWebKitWidgets[3443]
#define sipNameNr_scrollBarGeometry 3461
#define sipName_scrollBarGeometry &sipStrings_QtWebKitWidgets[3461]
#define sipNameNr_setScrollBarValue 3479
#define sipName_setScrollBarValue &sipStrings_QtWebKitWidgets[3479]
#define sipNameNr_setScrollPosition 3497
#define sipName_setScrollPosition &sipStrings_QtWebKitWidgets[3497]
#define sipNameNr_sip_simplewrapper 3515
#define sipName_sip_simplewrapper &sipStrings_QtWebKitWidgets[3515]
#define sipNameNr_supportsExtension 3533
#define sipName_supportsExtension &sipStrings_QtWebKitWidgets[3533]
#define sipNameNr_triggerPageAction 3551
#define sipName_triggerPageAction &sipStrings_QtWebKitWidgets[3551]
#define sipNameNr_DelegateAllLinks 3569
#define sipName_DelegateAllLinks &sipStrings_QtWebKitWidgets[3569]
#define sipNameNr_MoveToEndOfBlock 3586
#define sipName_MoveToEndOfBlock &sipStrings_QtWebKitWidgets[3586]
#define sipNameNr_PermissionPolicy 772
#define sipName_PermissionPolicy &sipStrings_QtWebKitWidgets[772]
#define sipNameNr_QGraphicsWebView 3603
#define sipName_QGraphicsWebView &sipStrings_QtWebKitWidgets[3603]
#define sipNameNr_SelectEndOfBlock 3620
#define sipName_SelectEndOfBlock &sipStrings_QtWebKitWidgets[3620]
#define sipNameNr_WebBrowserWindow 3637
#define sipName_WebBrowserWindow &sipStrings_QtWebKitWidgets[3637]
#define sipNameNr_collidesWithItem 3654
#define sipName_collidesWithItem &sipStrings_QtWebKitWidgets[3654]
#define sipNameNr_collidesWithPath 3671
#define sipName_collidesWithPath &sipStrings_QtWebKitWidgets[3671]
#define sipNameNr_contextMenuEvent 3688
#define sipName_contextMenuEvent &sipStrings_QtWebKitWidgets[3688]
#define sipNameNr_devicePixelRatio 3705
#define sipName_devicePixelRatio &sipStrings_QtWebKitWidgets[3705]
#define sipNameNr_disconnectNotify 3722
#define sipName_disconnectNotify &sipStrings_QtWebKitWidgets[3722]
#define sipNameNr_findFirstElement 3739
#define sipName_findFirstElement &sipStrings_QtWebKitWidgets[3739]
#define sipNameNr_inputMethodEvent 3756
#define sipName_inputMethodEvent &sipStrings_QtWebKitWidgets[3756]
#define sipNameNr_inputMethodQuery 3773
#define sipName_inputMethodQuery &sipStrings_QtWebKitWidgets[3773]
#define sipNameNr_javaScriptPrompt 3790
#define sipName_javaScriptPrompt &sipStrings_QtWebKitWidgets[3790]
#define sipNameNr_paintWindowFrame 3807
#define sipName_paintWindowFrame &sipStrings_QtWebKitWidgets[3807]
#define sipNameNr_repaintRequested 3824
#define sipName_repaintRequested &sipStrings_QtWebKitWidgets[3824]
#define sipNameNr_sceneEventFilter 3841
#define sipName_sceneEventFilter &sipStrings_QtWebKitWidgets[3841]
#define sipNameNr_scrollBarMaximum 3858
#define sipName_scrollBarMaximum &sipStrings_QtWebKitWidgets[3858]
#define sipNameNr_scrollBarMinimum 3875
#define sipName_scrollBarMinimum &sipStrings_QtWebKitWidgets[3875]
#define sipNameNr_selectionChanged 3892
#define sipName_selectionChanged &sipStrings_QtWebKitWidgets[3892]
#define sipNameNr_setPluginFactory 3909
#define sipName_setPluginFactory &sipStrings_QtWebKitWidgets[3909]
#define sipNameNr_statusBarMessage 3926
#define sipName_statusBarMessage &sipStrings_QtWebKitWidgets[3926]
#define sipNameNr_ungrabMouseEvent 3943
#define sipName_ungrabMouseEvent &sipStrings_QtWebKitWidgets[3943]
#define sipNameNr_windowFrameEvent 3960
#define sipName_windowFrameEvent &sipStrings_QtWebKitWidgets[3960]
#define sipNameNr_DeleteEndOfWord 3977
#define sipName_DeleteEndOfWord &sipStrings_QtWebKitWidgets[3977]
#define sipNameNr_ExtensionOption 29
#define sipName_ExtensionOption &sipStrings_QtWebKitWidgets[29]
#define sipNameNr_ExtensionReturn 74
#define sipName_ExtensionReturn &sipStrings_QtWebKitWidgets[74]
#define sipNameNr_MoveToEndOfLine 3993
#define sipName_MoveToEndOfLine &sipStrings_QtWebKitWidgets[3993]
#define sipNameNr_ScriptOwnership 4009
#define sipName_ScriptOwnership &sipStrings_QtWebKitWidgets[4009]
#define sipNameNr_SelectEndOfLine 4025
#define sipName_SelectEndOfLine &sipStrings_QtWebKitWidgets[4025]
#define sipNameNr_ToggleMediaLoop 4041
#define sipName_ToggleMediaLoop &sipStrings_QtWebKitWidgets[4041]
#define sipNameNr_ToggleMediaMute 4057
#define sipName_ToggleMediaMute &sipStrings_QtWebKitWidgets[4057]
#define sipNameNr_ToggleSubscript 4073
#define sipName_ToggleSubscript &sipStrings_QtWebKitWidgets[4073]
#define sipNameNr_ToggleUnderline 4089
#define sipName_ToggleUnderline &sipStrings_QtWebKitWidgets[4089]
#define sipNameNr_VisibilityState 984
#define sipName_VisibilityState &sipStrings_QtWebKitWidgets[984]
#define sipNameNr_contentsChanged 4105
#define sipName_contentsChanged &sipStrings_QtWebKitWidgets[4105]
#define sipNameNr_documentElement 4121
#define sipName_documentElement &sipStrings_QtWebKitWidgets[4121]
#define sipNameNr_findAllElements 4137
#define sipName_findAllElements &sipStrings_QtWebKitWidgets[4137]
#define sipNameNr_hoverEnterEvent 4153
#define sipName_hoverEnterEvent &sipStrings_QtWebKitWidgets[4153]
#define sipNameNr_hoverLeaveEvent 4169
#define sipName_hoverLeaveEvent &sipStrings_QtWebKitWidgets[4169]
#define sipNameNr_initStyleOption 4185
#define sipName_initStyleOption &sipStrings_QtWebKitWidgets[4185]
#define sipNameNr_javaScriptAlert 4201
#define sipName_javaScriptAlert &sipStrings_QtWebKitWidgets[4201]
#define sipNameNr_keyReleaseEvent 4217
#define sipName_keyReleaseEvent &sipStrings_QtWebKitWidgets[4217]
#define sipNameNr_linkTargetFrame 4233
#define sipName_linkTargetFrame &sipStrings_QtWebKitWidgets[4233]
#define sipNameNr_linkTitleString 4249
#define sipName_linkTitleString &sipStrings_QtWebKitWidgets[4249]
#define sipNameNr_minimumSizeHint 4265
#define sipName_minimumSizeHint &sipStrings_QtWebKitWidgets[4265]
#define sipNameNr_mousePressEvent 4281
#define sipName_mousePressEvent &sipStrings_QtWebKitWidgets[4281]
#define sipNameNr_scrollBarPolicy 4297
#define sipName_scrollBarPolicy &sipStrings_QtWebKitWidgets[4297]
#define sipNameNr_scrollRequested 4313
#define sipName_scrollRequested &sipStrings_QtWebKitWidgets[4313]
#define sipNameNr_setViewportSize 4329
#define sipName_setViewportSize &sipStrings_QtWebKitWidgets[4329]
#define sipNameNr_userAgentForUrl 4345
#define sipName_userAgentForUrl &sipStrings_QtWebKitWidgets[4345]
#define sipNameNr_visibilityState 4361
#define sipName_visibilityState &sipStrings_QtWebKitWidgets[4361]
#define sipNameNr_AlignJustified 4377
#define sipName_AlignJustified &sipStrings_QtWebKitWidgets[4377]
#define sipNameNr_InspectElement 4392
#define sipName_InspectElement &sipStrings_QtWebKitWidgets[4392]
#define sipNameNr_MoveToNextChar 4407
#define sipName_MoveToNextChar &sipStrings_QtWebKitWidgets[4407]
#define sipNameNr_MoveToNextLine 4422
#define sipName_MoveToNextLine &sipStrings_QtWebKitWidgets[4422]
#define sipNameNr_MoveToNextWord 4437
#define sipName_MoveToNextWord &sipStrings_QtWebKitWidgets[4437]
#define sipNameNr_NavigationType 1190
#define sipName_NavigationType &sipStrings_QtWebKitWidgets[1190]
#define sipNameNr_ScrollBarLayer 4452
#define sipName_ScrollBarLayer &sipStrings_QtWebKitWidgets[4452]
#define sipNameNr_SelectNextChar 4467
#define sipName_SelectNextChar &sipStrings_QtWebKitWidgets[4467]
#define sipNameNr_SelectNextLine 4482
#define sipName_SelectNextLine &sipStrings_QtWebKitWidgets[4482]
#define sipNameNr_SelectNextWord 4497
#define sipName_SelectNextWord &sipStrings_QtWebKitWidgets[4497]
#define sipNameNr_ValueOwnership 907
#define sipName_ValueOwnership &sipStrings_QtWebKitWidgets[907]
#define sipNameNr_WebModalDialog 4512
#define sipName_WebModalDialog &sipStrings_QtWebKitWidgets[4512]
#define sipNameNr_dragEnterEvent 4527
#define sipName_dragEnterEvent &sipStrings_QtWebKitWidgets[4527]
#define sipNameNr_dragLeaveEvent 4542
#define sipName_dragLeaveEvent &sipStrings_QtWebKitWidgets[4542]
#define sipNameNr_grabMouseEvent 3945
#define sipName_grabMouseEvent &sipStrings_QtWebKitWidgets[3945]
#define sipNameNr_heightForWidth 4557
#define sipName_heightForWidth &sipStrings_QtWebKitWidgets[4557]
#define sipNameNr_hitTestContent 4572
#define sipName_hitTestContent &sipStrings_QtWebKitWidgets[4572]
#define sipNameNr_hoverMoveEvent 4587
#define sipName_hoverMoveEvent &sipStrings_QtWebKitWidgets[4587]
#define sipNameNr_isUserScalable 4602
#define sipName_isUserScalable &sipStrings_QtWebKitWidgets[4602]
#define sipNameNr_mouseMoveEvent 4617
#define sipName_mouseMoveEvent &sipStrings_QtWebKitWidgets[4617]
#define sipNameNr_printRequested 4632
#define sipName_printRequested &sipStrings_QtWebKitWidgets[4632]
#define sipNameNr_scrollBarValue 4647
#define sipName_scrollBarValue &sipStrings_QtWebKitWidgets[4647]
#define sipNameNr_scrollPosition 4662
#define sipName_scrollPosition &sipStrings_QtWebKitWidgets[4662]
#define sipNameNr_scrollToAnchor 4677
#define sipName_scrollToAnchor &sipStrings_QtWebKitWidgets[4677]
#define sipNameNr_securityOrigin 4692
#define sipName_securityOrigin &sipStrings_QtWebKitWidgets[4692]
#define sipNameNr_setRenderHints 4707
#define sipName_setRenderHints &sipStrings_QtWebKitWidgets[4707]
#define sipNameNr_updateGeometry 4722
#define sipName_updateGeometry &sipStrings_QtWebKitWidgets[4722]
#define sipNameNr_AutoOwnership 4737
#define sipName_AutoOwnership &sipStrings_QtWebKitWidgets[4737]
#define sipNameNr_ContentsLayer 4751
#define sipName_ContentsLayer &sipStrings_QtWebKitWidgets[4751]
#define sipNameNr_Notifications 4765
#define sipName_Notifications &sipStrings_QtWebKitWidgets[4765]
#define sipNameNr_QWebInspector 4779
#define sipName_QWebInspector &sipStrings_QtWebKitWidgets[4779]
#define sipNameNr_WebWindowType 1459
#define sipName_WebWindowType &sipStrings_QtWebKitWidgets[1459]
#define sipNameNr_alternateText 4793
#define sipName_alternateText &sipStrings_QtWebKitWidgets[4793]
#define sipNameNr_bytesReceived 4807
#define sipName_bytesReceived &sipStrings_QtWebKitWidgets[4807]
#define sipNameNr_connectNotify 3725
#define sipName_connectNotify &sipStrings_QtWebKitWidgets[3725]
#define sipNameNr_dragMoveEvent 4821
#define sipName_dragMoveEvent &sipStrings_QtWebKitWidgets[4821]
#define sipNameNr_focusOutEvent 4835
#define sipName_focusOutEvent &sipStrings_QtWebKitWidgets[4835]
#define sipNameNr_keyPressEvent 4849
#define sipName_keyPressEvent &sipStrings_QtWebKitWidgets[4849]
#define sipNameNr_pluginFactory 4863
#define sipName_pluginFactory &sipStrings_QtWebKitWidgets[4863]
#define sipNameNr_setRenderHint 4877
#define sipName_setRenderHint &sipStrings_QtWebKitWidgets[4877]
#define sipNameNr_setZoomFactor 4891
#define sipName_setZoomFactor &sipStrings_QtWebKitWidgets[4891]
#define sipNameNr_sharedPainter 4905
#define sipName_sharedPainter &sipStrings_QtWebKitWidgets[4905]
#define sipNameNr_triggerAction 4919
#define sipName_triggerAction &sipStrings_QtWebKitWidgets[4919]
#define sipNameNr_FindBackward 4933
#define sipName_FindBackward &sipStrings_QtWebKitWidgets[4933]
#define sipNameNr_PanIconLayer 4946
#define sipName_PanIconLayer &sipStrings_QtWebKitWidgets[4946]
#define sipNameNr_RemoveFormat 4959
#define sipName_RemoveFormat &sipStrings_QtWebKitWidgets[4959]
#define sipNameNr_RenderLayers 1436
#define sipName_RenderLayers &sipStrings_QtWebKitWidgets[1436]
#define sipNameNr_ToggleItalic 4972
#define sipName_ToggleItalic &sipStrings_QtWebKitWidgets[4972]
#define sipNameNr_boundingRect 4985
#define sipName_boundingRect &sipStrings_QtWebKitWidgets[4985]
#define sipNameNr_contentsSize 4998
#define sipName_contentsSize &sipStrings_QtWebKitWidgets[4998]
#define sipNameNr_createPlugin 5011
#define sipName_createPlugin &sipStrings_QtWebKitWidgets[5011]
#define sipNameNr_createWindow 5024
#define sipName_createWindow &sipStrings_QtWebKitWidgets[5024]
#define sipNameNr_currentFrame 5037
#define sipName_currentFrame &sipStrings_QtWebKitWidgets[5037]
#define sipNameNr_focusInEvent 5050
#define sipName_focusInEvent &sipStrings_QtWebKitWidgets[5050]
#define sipNameNr_frameCreated 5063
#define sipName_frameCreated &sipStrings_QtWebKitWidgets[5063]
#define sipNameNr_hasSelection 5076
#define sipName_hasSelection &sipStrings_QtWebKitWidgets[5076]
#define sipNameNr_isObscuredBy 5089
#define sipName_isObscuredBy &sipStrings_QtWebKitWidgets[5089]
#define sipNameNr_loadFinished 5102
#define sipName_loadFinished &sipStrings_QtWebKitWidgets[5102]
#define sipNameNr_loadProgress 5115
#define sipName_loadProgress &sipStrings_QtWebKitWidgets[5115]
#define sipNameNr_requestedUrl 5128
#define sipName_requestedUrl &sipStrings_QtWebKitWidgets[5128]
#define sipNameNr_selectedHtml 5141
#define sipName_selectedHtml &sipStrings_QtWebKitWidgets[5141]
#define sipNameNr_selectedText 5154
#define sipName_selectedText &sipStrings_QtWebKitWidgets[5154]
#define sipNameNr_titleChanged 5167
#define sipName_titleChanged &sipStrings_QtWebKitWidgets[5167]
#define sipNameNr_viewportSize 5180
#define sipName_viewportSize &sipStrings_QtWebKitWidgets[5180]
#define sipNameNr_AlignCenter 5193
#define sipName_AlignCenter &sipStrings_QtWebKitWidgets[5193]
#define sipNameNr_ErrorDomain 1879
#define sipName_ErrorDomain &sipStrings_QtWebKitWidgets[1879]
#define sipNameNr_Geolocation 5205
#define sipName_Geolocation &sipStrings_QtWebKitWidgets[5205]
#define sipNameNr_NoWebAction 5217
#define sipName_NoWebAction &sipStrings_QtWebKitWidgets[5217]
#define sipNameNr_QtOwnership 5229
#define sipName_QtOwnership &sipStrings_QtWebKitWidgets[5229]
#define sipNameNr_RenderLayer 1723
#define sipName_RenderLayer &sipStrings_QtWebKitWidgets[1723]
#define sipNameNr_actionEvent 5241
#define sipName_actionEvent &sipStrings_QtWebKitWidgets[5241]
#define sipNameNr_changeEvent 5253
#define sipName_changeEvent &sipStrings_QtWebKitWidgets[5253]
#define sipNameNr_childFrames 5265
#define sipName_childFrames &sipStrings_QtWebKitWidgets[5265]
#define sipNameNr_contentType 5277
#define sipName_contentType &sipStrings_QtWebKitWidgets[5277]
#define sipNameNr_customEvent 5289
#define sipName_customEvent &sipStrings_QtWebKitWidgets[5289]
#define sipNameNr_errorString 5301
#define sipName_errorString &sipStrings_QtWebKitWidgets[5301]
#define sipNameNr_eventFilter 5313
#define sipName_eventFilter &sipStrings_QtWebKitWidgets[5313]
#define sipNameNr_iconChanged 5325
#define sipName_iconChanged &sipStrings_QtWebKitWidgets[5325]
#define sipNameNr_initPainter 5337
#define sipName_initPainter &sipStrings_QtWebKitWidgets[5337]
#define sipNameNr_linkClicked 5349
#define sipName_linkClicked &sipStrings_QtWebKitWidgets[5349]
#define sipNameNr_linkElement 5361
#define sipName_linkElement &sipStrings_QtWebKitWidgets[5361]
#define sipNameNr_linkHovered 5373
#define sipName_linkHovered &sipStrings_QtWebKitWidgets[5373]
#define sipNameNr_loadStarted 5385
#define sipName_loadStarted &sipStrings_QtWebKitWidgets[5385]
#define sipNameNr_nativeEvent 5397
#define sipName_nativeEvent &sipStrings_QtWebKitWidgets[5397]
#define sipNameNr_pageChanged 5409
#define sipName_pageChanged &sipStrings_QtWebKitWidgets[5409]
#define sipNameNr_paintEngine 5421
#define sipName_paintEngine &sipStrings_QtWebKitWidgets[5421]
#define sipNameNr_parentFrame 5433
#define sipName_parentFrame &sipStrings_QtWebKitWidgets[5433]
#define sipNameNr_polishEvent 5445
#define sipName_polishEvent &sipStrings_QtWebKitWidgets[5445]
#define sipNameNr_renderHints 5457
#define sipName_renderHints &sipStrings_QtWebKitWidgets[5457]
#define sipNameNr_resizeEvent 5469
#define sipName_resizeEvent &sipStrings_QtWebKitWidgets[5469]
#define sipNameNr_setGeometry 5481
#define sipName_setGeometry &sipStrings_QtWebKitWidgets[5481]
#define sipNameNr_tabletEvent 5493
#define sipName_tabletEvent &sipStrings_QtWebKitWidgets[5493]
#define sipNameNr_toPlainText 5505
#define sipName_toPlainText &sipStrings_QtWebKitWidgets[5505]
#define sipNameNr_AlignRight 5517
#define sipName_AlignRight &sipStrings_QtWebKitWidgets[5517]
#define sipNameNr_ToggleBold 5528
#define sipName_ToggleBold &sipStrings_QtWebKitWidgets[5528]
#define sipNameNr___invert__ 5539
#define sipName___invert__ &sipStrings_QtWebKitWidgets[5539]
#define sipNameNr_childEvent 5550
#define sipName_childEvent &sipStrings_QtWebKitWidgets[5550]
#define sipNameNr_chooseFile 5561
#define sipName_chooseFile &sipStrings_QtWebKitWidgets[5561]
#define sipNameNr_closeEvent 5572
#define sipName_closeEvent &sipStrings_QtWebKitWidgets[5572]
#define sipNameNr_enterEvent 5583
#define sipName_enterEvent &sipStrings_QtWebKitWidgets[5583]
#define sipNameNr_isModified 5594
#define sipName_isModified &sipStrings_QtWebKitWidgets[5594]
#define sipNameNr_itemChange 5605
#define sipName_itemChange &sipStrings_QtWebKitWidgets[5605]
#define sipNameNr_leaveEvent 5616
#define sipName_leaveEvent &sipStrings_QtWebKitWidgets[5616]
#define sipNameNr_opaqueArea 5627
#define sipName_opaqueArea &sipStrings_QtWebKitWidgets[5627]
#define sipNameNr_pageAction 5638
#define sipName_pageAction &sipStrings_QtWebKitWidgets[5638]
#define sipNameNr_paintEvent 5649
#define sipName_paintEvent &sipStrings_QtWebKitWidgets[5649]
#define sipNameNr_sceneEvent 5660
#define sipName_sceneEvent &sipStrings_QtWebKitWidgets[5660]
#define sipNameNr_setContent 5671
#define sipName_setContent &sipStrings_QtWebKitWidgets[5671]
#define sipNameNr_setPalette 5682
#define sipName_setPalette &sipStrings_QtWebKitWidgets[5682]
#define sipNameNr_setVisible 5693
#define sipName_setVisible &sipStrings_QtWebKitWidgets[5693]
#define sipNameNr_timerEvent 5704
#define sipName_timerEvent &sipStrings_QtWebKitWidgets[5704]
#define sipNameNr_totalBytes 5715
#define sipName_totalBytes &sipStrings_QtWebKitWidgets[5715]
#define sipNameNr_urlChanged 5726
#define sipName_urlChanged &sipStrings_QtWebKitWidgets[5726]
#define sipNameNr_wheelEvent 5737
#define sipName_wheelEvent &sipStrings_QtWebKitWidgets[5737]
#define sipNameNr_zoomFactor 5748
#define sipName_zoomFactor &sipStrings_QtWebKitWidgets[5748]
#define sipNameNr_AlignLeft 5759
#define sipName_AlignLeft &sipStrings_QtWebKitWidgets[5759]
#define sipNameNr_AllLayers 5769
#define sipName_AllLayers &sipStrings_QtWebKitWidgets[5769]
#define sipNameNr_Extension 499
#define sipName_Extension &sipStrings_QtWebKitWidgets[499]
#define sipNameNr_FindFlags 2550
#define sipName_FindFlags &sipStrings_QtWebKitWidgets[2550]
#define sipNameNr_QWebFrame 5779
#define sipName_QWebFrame &sipStrings_QtWebKitWidgets[5779]
#define sipNameNr_QtNetwork 5789
#define sipName_QtNetwork &sipStrings_QtWebKitWidgets[5789]
#define sipNameNr_SelectAll 5799
#define sipName_SelectAll &sipStrings_QtWebKitWidgets[5799]
#define sipNameNr_WebAction 2570
#define sipName_WebAction &sipStrings_QtWebKitWidgets[2570]
#define sipNameNr___index__ 5809
#define sipName___index__ &sipStrings_QtWebKitWidgets[5809]
#define sipNameNr_dropEvent 5819
#define sipName_dropEvent &sipStrings_QtWebKitWidgets[5819]
#define sipNameNr_extension 5829
#define sipName_extension &sipStrings_QtWebKitWidgets[5829]
#define sipNameNr_fileNames 5839
#define sipName_fileNames &sipStrings_QtWebKitWidgets[5839]
#define sipNameNr_frameName 5849
#define sipName_frameName &sipStrings_QtWebKitWidgets[5849]
#define sipNameNr_hideEvent 5859
#define sipName_hideEvent &sipStrings_QtWebKitWidgets[5859]
#define sipNameNr_linkTitle 5869
#define sipName_linkTitle &sipStrings_QtWebKitWidgets[5869]
#define sipNameNr_mainFrame 5879
#define sipName_mainFrame &sipStrings_QtWebKitWidgets[5879]
#define sipNameNr_moveEvent 5889
#define sipName_moveEvent &sipStrings_QtWebKitWidgets[5889]
#define sipNameNr_operation 5899
#define sipName_operation &sipStrings_QtWebKitWidgets[5899]
#define sipNameNr_ownership 5909
#define sipName_ownership &sipStrings_QtWebKitWidgets[5909]
#define sipNameNr_showEvent 5919
#define sipName_showEvent &sipStrings_QtWebKitWidgets[5919]
#define sipNameNr_undoStack 5929
#define sipName_undoStack &sipStrings_QtWebKitWidgets[5929]
#define sipNameNr_FindFlag 2843
#define sipName_FindFlag &sipStrings_QtWebKitWidgets[2843]
#define sipNameNr_OpenLink 5939
#define sipName_OpenLink &sipStrings_QtWebKitWidgets[5939]
#define sipNameNr_QWebPage 5948
#define sipName_QWebPage &sipStrings_QtWebKitWidgets[5948]
#define sipNameNr_QWebView 5957
#define sipName_QWebView &sipStrings_QtWebKitWidgets[5957]
#define sipNameNr___bool__ 5966
#define sipName___bool__ &sipStrings_QtWebKitWidgets[5966]
#define sipNameNr___hash__ 5975
#define sipName___hash__ &sipStrings_QtWebKitWidgets[5975]
#define sipNameNr___iand__ 5984
#define sipName___iand__ &sipStrings_QtWebKitWidgets[5984]
#define sipNameNr___ixor__ 5993
#define sipName___ixor__ &sipStrings_QtWebKitWidgets[5993]
#define sipNameNr_contains 6002
#define sipName_contains &sipStrings_QtWebKitWidgets[6002]
#define sipNameNr_encoding 6011
#define sipName_encoding &sipStrings_QtWebKitWidgets[6011]
#define sipNameNr_findText 6020
#define sipName_findText &sipStrings_QtWebKitWidgets[6020]
#define sipNameNr_geometry 6029
#define sipName_geometry &sipStrings_QtWebKitWidgets[6029]
#define sipNameNr_hasFocus 6038
#define sipName_hasFocus &sipStrings_QtWebKitWidgets[6038]
#define sipNameNr_imageUrl 6047
#define sipName_imageUrl &sipStrings_QtWebKitWidgets[6047]
#define sipNameNr_linkText 6056
#define sipName_linkText &sipStrings_QtWebKitWidgets[6056]
#define sipNameNr_mediaUrl 6065
#define sipName_mediaUrl &sipStrings_QtWebKitWidgets[6065]
#define sipNameNr_metaData 6074
#define sipName_metaData &sipStrings_QtWebKitWidgets[6074]
#define sipNameNr_mimeType 6083
#define sipName_mimeType &sipStrings_QtWebKitWidgets[6083]
#define sipNameNr_setFocus 6092
#define sipName_setFocus &sipStrings_QtWebKitWidgets[6092]
#define sipNameNr_settings 6101
#define sipName_settings &sipStrings_QtWebKitWidgets[6101]
#define sipNameNr_sizeHint 6110
#define sipName_sizeHint &sipStrings_QtWebKitWidgets[6110]
#define sipNameNr_Feature 3273
#define sipName_Feature &sipStrings_QtWebKitWidgets[3273]
#define sipNameNr_Forward 587
#define sipName_Forward &sipStrings_QtWebKitWidgets[587]
#define sipNameNr_Outdent 6119
#define sipName_Outdent &sipStrings_QtWebKitWidgets[6119]
#define sipNameNr___and__ 6127
#define sipName___and__ &sipStrings_QtWebKitWidgets[6127]
#define sipNameNr___int__ 6135
#define sipName___int__ &sipStrings_QtWebKitWidgets[6135]
#define sipNameNr___ior__ 6143
#define sipName___ior__ &sipStrings_QtWebKitWidgets[6143]
#define sipNameNr___xor__ 6151
#define sipName___xor__ &sipStrings_QtWebKitWidgets[6151]
#define sipNameNr_advance 6159
#define sipName_advance &sipStrings_QtWebKitWidgets[6159]
#define sipNameNr_baseUrl 6167
#define sipName_baseUrl &sipStrings_QtWebKitWidgets[6167]
#define sipNameNr_checked 6175
#define sipName_checked &sipStrings_QtWebKitWidgets[6175]
#define sipNameNr_content 6183
#define sipName_content &sipStrings_QtWebKitWidgets[6183]
#define sipNameNr_devType 6191
#define sipName_devType &sipStrings_QtWebKitWidgets[6191]
#define sipNameNr_element 6199
#define sipName_element &sipStrings_QtWebKitWidgets[6199]
#define sipNameNr_enabled 6207
#define sipName_enabled &sipStrings_QtWebKitWidgets[6207]
#define sipNameNr_forward 6215
#define sipName_forward &sipStrings_QtWebKitWidgets[6215]
#define sipNameNr_frameAt 6223
#define sipName_frameAt &sipStrings_QtWebKitWidgets[6223]
#define sipNameNr_history 6231
#define sipName_history &sipStrings_QtWebKitWidgets[6231]
#define sipNameNr_isValid 6239
#define sipName_isValid &sipStrings_QtWebKitWidgets[6239]
#define sipNameNr_linkUrl 6247
#define sipName_linkUrl &sipStrings_QtWebKitWidgets[6247]
#define sipNameNr_options 6255
#define sipName_options &sipStrings_QtWebKitWidgets[6255]
#define sipNameNr_palette 6263
#define sipName_palette &sipStrings_QtWebKitWidgets[6263]
#define sipNameNr_setHtml 6271
#define sipName_setHtml &sipStrings_QtWebKitWidgets[6271]
#define sipNameNr_setPage 6279
#define sipName_setPage &sipStrings_QtWebKitWidgets[6279]
#define sipNameNr_setView 6287
#define sipName_setView &sipStrings_QtWebKitWidgets[6287]
#define sipNameNr_Indent 6295
#define sipName_Indent &sipStrings_QtWebKitWidgets[6295]
#define sipNameNr_Reload 2102
#define sipName_Reload &sipStrings_QtWebKitWidgets[2102]
#define sipNameNr_WebKit 6302
#define sipName_WebKit &sipStrings_QtWebKitWidgets[6302]
#define sipNameNr___eq__ 6309
#define sipName___eq__ &sipStrings_QtWebKitWidgets[6309]
#define sipNameNr___ne__ 6316
#define sipName___ne__ &sipStrings_QtWebKitWidgets[6316]
#define sipNameNr___or__ 6323
#define sipName___or__ &sipStrings_QtWebKitWidgets[6323]
#define sipNameNr_action 6330
#define sipName_action &sipStrings_QtWebKitWidgets[6330]
#define sipNameNr_domain 6337
#define sipName_domain &sipStrings_QtWebKitWidgets[6337]
#define sipNameNr_isNull 6344
#define sipName_isNull &sipStrings_QtWebKitWidgets[6344]
#define sipNameNr_metric 6351
#define sipName_metric &sipStrings_QtWebKitWidgets[6351]
#define sipNameNr_option 6358
#define sipName_option &sipStrings_QtWebKitWidgets[6358]
#define sipNameNr_output 6365
#define sipName_output &sipStrings_QtWebKitWidgets[6365]
#define sipNameNr_parent 6372
#define sipName_parent &sipStrings_QtWebKitWidgets[6372]
#define sipNameNr_pixmap 6379
#define sipName_pixmap &sipStrings_QtWebKitWidgets[6379]
#define sipNameNr_print_ 6386
#define sipName_print_ &sipStrings_QtWebKitWidgets[6386]
#define sipNameNr_reload 6393
#define sipName_reload &sipStrings_QtWebKitWidgets[6393]
#define sipNameNr_render 1248
#define sipName_render &sipStrings_QtWebKitWidgets[1248]
#define sipNameNr_scroll 6400
#define sipName_scroll &sipStrings_QtWebKitWidgets[6400]
#define sipNameNr_setUrl 6407
#define sipName_setUrl &sipStrings_QtWebKitWidgets[6407]
#define sipNameNr_toHtml 6414
#define sipName_toHtml &sipStrings_QtWebKitWidgets[6414]
#define sipNameNr_widget 6421
#define sipName_widget &sipStrings_QtWebKitWidgets[6421]
#define sipNameNr_Paste 6428
#define sipName_Paste &sipStrings_QtWebKitWidgets[6428]
#define sipNameNr_error 6434
#define sipName_error &sipStrings_QtWebKitWidgets[6434]
#define sipNameNr_event 6440
#define sipName_event &sipStrings_QtWebKitWidgets[6440]
#define sipNameNr_frame 6446
#define sipName_frame &sipStrings_QtWebKitWidgets[6446]
#define sipNameNr_paint 6452
#define sipName_paint &sipStrings_QtWebKitWidgets[6452]
#define sipNameNr_print 6458
#define sipName_print &sipStrings_QtWebKitWidgets[6458]
#define sipNameNr_shape 6464
#define sipName_shape &sipStrings_QtWebKitWidgets[6464]
#define sipNameNr_title 6470
#define sipName_title &sipStrings_QtWebKitWidgets[6470]
#define sipNameNr_Back 6476
#define sipName_Back &sipStrings_QtWebKitWidgets[6476]
#define sipNameNr_Copy 6481
#define sipName_Copy &sipStrings_QtWebKitWidgets[6481]
#define sipNameNr_Http 6486
#define sipName_Http &sipStrings_QtWebKitWidgets[6486]
#define sipNameNr_Redo 6491
#define sipName_Redo &sipStrings_QtWebKitWidgets[6491]
#define sipNameNr_Stop 6496
#define sipName_Stop &sipStrings_QtWebKitWidgets[6496]
#define sipNameNr_Undo 6501
#define sipName_Undo &sipStrings_QtWebKitWidgets[6501]
#define sipNameNr_back 6506
#define sipName_back &sipStrings_QtWebKitWidgets[6506]
#define sipNameNr_body 6511
#define sipName_body &sipStrings_QtWebKitWidgets[6511]
#define sipNameNr_clip 6516
#define sipName_clip &sipStrings_QtWebKitWidgets[6516]
#define sipNameNr_icon 6521
#define sipName_icon &sipStrings_QtWebKitWidgets[6521]
#define sipNameNr_load 2104
#define sipName_load &sipStrings_QtWebKitWidgets[2104]
#define sipNameNr_page 6526
#define sipName_page &sipStrings_QtWebKitWidgets[6526]
#define sipNameNr_size 6531
#define sipName_size &sipStrings_QtWebKitWidgets[6531]
#define sipNameNr_stop 6536
#define sipName_stop &sipStrings_QtWebKitWidgets[6536]
#define sipNameNr_type 6541
#define sipName_type &sipStrings_QtWebKitWidgets[6541]
#define sipNameNr_view 6546
#define sipName_view &sipStrings_QtWebKitWidgets[6546]
#define sipNameNr_Cut 6551
#define sipName_Cut &sipStrings_QtWebKitWidgets[6551]
#define sipNameNr_pos 6555
#define sipName_pos &sipStrings_QtWebKitWidgets[6555]
#define sipNameNr_url 6559
#define sipName_url &sipStrings_QtWebKitWidgets[6559]

#define sipMalloc                   sipAPI_QtWebKitWidgets->api_malloc
#define sipFree                     sipAPI_QtWebKitWidgets->api_free
#define sipBuildResult              sipAPI_QtWebKitWidgets->api_build_result
#define sipCallMethod               sipAPI_QtWebKitWidgets->api_call_method
#define sipCallProcedureMethod      sipAPI_QtWebKitWidgets->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtWebKitWidgets->api_call_error_handler
#define sipParseResultEx            sipAPI_QtWebKitWidgets->api_parse_result_ex
#define sipParseResult              sipAPI_QtWebKitWidgets->api_parse_result
#define sipParseArgs                sipAPI_QtWebKitWidgets->api_parse_args
#define sipParseKwdArgs             sipAPI_QtWebKitWidgets->api_parse_kwd_args
#define sipParsePair                sipAPI_QtWebKitWidgets->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtWebKitWidgets->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtWebKitWidgets->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtWebKitWidgets->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtWebKitWidgets->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtWebKitWidgets->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtWebKitWidgets->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtWebKitWidgets->api_add_exception
#define sipNoFunction               sipAPI_QtWebKitWidgets->api_no_function
#define sipNoMethod                 sipAPI_QtWebKitWidgets->api_no_method
#define sipAbstractMethod           sipAPI_QtWebKitWidgets->api_abstract_method
#define sipBadClass                 sipAPI_QtWebKitWidgets->api_bad_class
#define sipBadCatcherResult         sipAPI_QtWebKitWidgets->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtWebKitWidgets->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtWebKitWidgets->api_bad_operator_arg
#define sipTrace                    sipAPI_QtWebKitWidgets->api_trace
#define sipTransferBack             sipAPI_QtWebKitWidgets->api_transfer_back
#define sipTransferTo               sipAPI_QtWebKitWidgets->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtWebKitWidgets->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtWebKitWidgets->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtWebKitWidgets->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtWebKitWidgets->api_voidptr_type
#define sipGetPyObject              sipAPI_QtWebKitWidgets->api_get_pyobject
#define sipGetAddress               sipAPI_QtWebKitWidgets->api_get_address
#define sipGetMixinAddress          sipAPI_QtWebKitWidgets->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtWebKitWidgets->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtWebKitWidgets->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtWebKitWidgets->api_call_hook
#define sipEndThread                sipAPI_QtWebKitWidgets->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtWebKitWidgets->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtWebKitWidgets->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtWebKitWidgets->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtWebKitWidgets->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtWebKitWidgets->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtWebKitWidgets->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtWebKitWidgets->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtWebKitWidgets->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtWebKitWidgets->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtWebKitWidgets->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtWebKitWidgets->api_convert_to_bool
#define sipReleaseType              sipAPI_QtWebKitWidgets->api_release_type
#define sipConvertFromType          sipAPI_QtWebKitWidgets->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtWebKitWidgets->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtWebKitWidgets->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtWebKitWidgets->api_convert_from_enum
#define sipGetState                 sipAPI_QtWebKitWidgets->api_get_state
#define sipExportSymbol             sipAPI_QtWebKitWidgets->api_export_symbol
#define sipImportSymbol             sipAPI_QtWebKitWidgets->api_import_symbol
#define sipFindType                 sipAPI_QtWebKitWidgets->api_find_type
#define sipBytes_AsChar             sipAPI_QtWebKitWidgets->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtWebKitWidgets->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtWebKitWidgets->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtWebKitWidgets->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtWebKitWidgets->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtWebKitWidgets->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtWebKitWidgets->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtWebKitWidgets->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtWebKitWidgets->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtWebKitWidgets->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtWebKitWidgets->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtWebKitWidgets->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtWebKitWidgets->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtWebKitWidgets->api_get_reference
#define sipKeepReference            sipAPI_QtWebKitWidgets->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtWebKitWidgets->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtWebKitWidgets->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtWebKitWidgets->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtWebKitWidgets->api_type_scope
#define sipResolveTypedef           sipAPI_QtWebKitWidgets->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtWebKitWidgets->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtWebKitWidgets->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtWebKitWidgets->api_init_mixin
#define sipExportModule             sipAPI_QtWebKitWidgets->api_export_module
#define sipInitModule               sipAPI_QtWebKitWidgets->api_init_module
#define sipGetInterpreter           sipAPI_QtWebKitWidgets->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtWebKitWidgets->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtWebKitWidgets->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtWebKitWidgets->api_py_type_dict
#define sipPyTypeName               sipAPI_QtWebKitWidgets->api_py_type_name
#define sipGetCFunction             sipAPI_QtWebKitWidgets->api_get_c_function
#define sipGetMethod                sipAPI_QtWebKitWidgets->api_get_method
#define sipFromMethod               sipAPI_QtWebKitWidgets->api_from_method
#define sipGetDate                  sipAPI_QtWebKitWidgets->api_get_date
#define sipFromDate                 sipAPI_QtWebKitWidgets->api_from_date
#define sipGetDateTime              sipAPI_QtWebKitWidgets->api_get_datetime
#define sipFromDateTime             sipAPI_QtWebKitWidgets->api_from_datetime
#define sipGetTime                  sipAPI_QtWebKitWidgets->api_get_time
#define sipFromTime                 sipAPI_QtWebKitWidgets->api_from_time
#define sipIsUserType               sipAPI_QtWebKitWidgets->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtWebKitWidgets->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtWebKitWidgets->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtWebKitWidgets->api_unicode_write
#define sipUnicodeData              sipAPI_QtWebKitWidgets->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtWebKitWidgets->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtWebKitWidgets->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtWebKitWidgets->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtWebKitWidgets->api_is_derived_class
#define sipGetUserObject            sipAPI_QtWebKitWidgets->api_get_user_object
#define sipSetUserObject            sipAPI_QtWebKitWidgets->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtWebKitWidgets->api_register_event_handler
#define sipConvertToArray           sipAPI_QtWebKitWidgets->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtWebKitWidgets->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtWebKitWidgets->api_enable_gc
#define sipPrintObject              sipAPI_QtWebKitWidgets->api_print_object
#define sipLong_AsChar              sipAPI_QtWebKitWidgets->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtWebKitWidgets->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtWebKitWidgets->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtWebKitWidgets->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtWebKitWidgets->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtWebKitWidgets->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtWebKitWidgets->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtWebKitWidgets->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtWebKitWidgets->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtWebKitWidgets->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtWebKitWidgets->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtWebKitWidgets->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtWebKitWidgets->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtWebKitWidgets->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtWebKitWidgets->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtWebKitWidgets->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtWebKitWidgets->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtWebKitWidgets->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtWebKitWidgets->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtWebKitWidgets->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtWebKitWidgets->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtWebKitWidgets->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtWebKitWidgets->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtWebKitWidgets->api_connect_rx
#define sipConvertRx                sipAPI_QtWebKitWidgets->api_convert_rx
#define sipDisconnectRx             sipAPI_QtWebKitWidgets->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtWebKitWidgets->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtWebKitWidgets->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtWebKitWidgets->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtWebKitWidgets->api_same_slot
#define sipSaveSlot                 sipAPI_QtWebKitWidgets->api_save_slot
#define sipVisitSlot                sipAPI_QtWebKitWidgets->api_visit_slot
#define sipIsPyMethod               sipAPI_QtWebKitWidgets->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtWebKitWidgets[];

#define sipType_QGraphicsWebView sipExportedTypes_QtWebKitWidgets[0]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QGraphicsWebView;

#define sipType_QWebHitTestResult sipExportedTypes_QtWebKitWidgets[7]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebHitTestResult;

#define sipType_QWebFrame sipExportedTypes_QtWebKitWidgets[3]

#define sipType_QWebFrame_RenderLayer sipExportedTypes_QtWebKitWidgets[4]

#define sipType_QWebFrame_ValueOwnership sipExportedTypes_QtWebKitWidgets[6]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebFrame;

#define sipType_QWebFrame_RenderLayers sipExportedTypes_QtWebKitWidgets[5]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebFrame_RenderLayers;

#define sipType_QWebInspector sipExportedTypes_QtWebKitWidgets[8]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebInspector;

#define sipType_QWebPage sipExportedTypes_QtWebKitWidgets[9]

#define sipType_QWebPage_VisibilityState sipExportedTypes_QtWebKitWidgets[25]

#define sipType_QWebPage_Feature sipExportedTypes_QtWebKitWidgets[18]

#define sipType_QWebPage_PermissionPolicy sipExportedTypes_QtWebKitWidgets[23]

#define sipType_QWebPage_ErrorDomain sipExportedTypes_QtWebKitWidgets[12]

#define sipType_QWebPage_Extension sipExportedTypes_QtWebKitWidgets[15]

#define sipType_QWebPage_WebWindowType sipExportedTypes_QtWebKitWidgets[27]

#define sipType_QWebPage_LinkDelegationPolicy sipExportedTypes_QtWebKitWidgets[21]

#define sipType_QWebPage_FindFlag sipExportedTypes_QtWebKitWidgets[19]

#define sipType_QWebPage_WebAction sipExportedTypes_QtWebKitWidgets[26]

#define sipType_QWebPage_NavigationType sipExportedTypes_QtWebKitWidgets[22]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage;

#define sipType_QWebPage_FindFlags sipExportedTypes_QtWebKitWidgets[20]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_FindFlags;

#define sipType_QWebPage_ExtensionOption sipExportedTypes_QtWebKitWidgets[16]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ExtensionOption;

#define sipType_QWebPage_ExtensionReturn sipExportedTypes_QtWebKitWidgets[17]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ExtensionReturn;

#define sipType_QWebPage_ChooseMultipleFilesExtensionOption sipExportedTypes_QtWebKitWidgets[10]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ChooseMultipleFilesExtensionOption;

#define sipType_QWebPage_ChooseMultipleFilesExtensionReturn sipExportedTypes_QtWebKitWidgets[11]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ChooseMultipleFilesExtensionReturn;

#define sipType_QWebPage_ErrorPageExtensionOption sipExportedTypes_QtWebKitWidgets[13]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ErrorPageExtensionOption;

#define sipType_QWebPage_ErrorPageExtensionReturn sipExportedTypes_QtWebKitWidgets[14]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ErrorPageExtensionReturn;

#define sipType_QWebPage_ViewportAttributes sipExportedTypes_QtWebKitWidgets[24]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage_ViewportAttributes;

#define sipType_QWebView sipExportedTypes_QtWebKitWidgets[28]

extern sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebView;

#define sipType_QMultiMap_0100QString_0100QString sipExportedTypes_QtWebKitWidgets[2]

extern sipMappedTypeDef sipTypeDef_QtWebKitWidgets_QMultiMap_0100QString_0100QString;

#define sipType_QList_0101QWebFrame sipExportedTypes_QtWebKitWidgets[1]

extern sipMappedTypeDef sipTypeDef_QtWebKitWidgets_QList_0101QWebFrame;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtWebKitWidgets;
extern sipExportedModuleDef sipModuleAPI_QtWebKitWidgets;
extern sipTypeDef *sipExportedTypes_QtWebKitWidgets[];

#define sipType_Qt_WindowFrameSection sipImportedTypes_QtWebKitWidgets_QtCore[21].it_td

#define sipType_Qt_SizeHint sipImportedTypes_QtWebKitWidgets_QtCore[20].it_td

#define sipType_Qt_ItemSelectionMode sipImportedTypes_QtWebKitWidgets_QtCore[17].it_td

#define sipType_Qt_InputMethodQuery sipImportedTypes_QtWebKitWidgets_QtCore[16].it_td

#define sipType_Qt_ScrollBarPolicy sipImportedTypes_QtWebKitWidgets_QtCore[19].it_td

#define sipType_Qt_Orientation sipImportedTypes_QtWebKitWidgets_QtCore[18].it_td

#define sipType_QObject sipImportedTypes_QtWebKitWidgets_QtCore[4].it_td

#define sipType_QByteArray sipImportedTypes_QtWebKitWidgets_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtWebKitWidgets_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtWebKitWidgets_QtCore[13].it_td

#define sipType_QChildEvent sipImportedTypes_QtWebKitWidgets_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtWebKitWidgets_QtCore[3].it_td

#define sipType_QPoint sipImportedTypes_QtWebKitWidgets_QtCore[5].it_td

#define sipType_QPointF sipImportedTypes_QtWebKitWidgets_QtCore[6].it_td

#define sipType_QRect sipImportedTypes_QtWebKitWidgets_QtCore[7].it_td

#define sipType_QRectF sipImportedTypes_QtWebKitWidgets_QtCore[8].it_td

#define sipType_QSize sipImportedTypes_QtWebKitWidgets_QtCore[9].it_td

#define sipType_QSizeF sipImportedTypes_QtWebKitWidgets_QtCore[10].it_td

#define sipType_QUrl sipImportedTypes_QtWebKitWidgets_QtCore[14].it_td

#define sipType_QVariant sipImportedTypes_QtWebKitWidgets_QtCore[15].it_td

#define sipType_QStringList sipImportedTypes_QtWebKitWidgets_QtCore[12].it_td

#define sipType_QString sipImportedTypes_QtWebKitWidgets_QtCore[11].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[];

#define sipType_QNetworkAccessManager sipImportedTypes_QtWebKitWidgets_QtNetwork[0].it_td

#define sipType_QNetworkAccessManager_Operation sipImportedTypes_QtWebKitWidgets_QtNetwork[1].it_td

#define sipType_QNetworkReply sipImportedTypes_QtWebKitWidgets_QtNetwork[2].it_td

#define sipType_QNetworkRequest sipImportedTypes_QtWebKitWidgets_QtNetwork[3].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtNetwork[];

#define sipType_QPaintDevice sipImportedTypes_QtWebKitWidgets_QtGui[14].it_td

#define sipType_QPaintDevice_PaintDeviceMetric sipImportedTypes_QtWebKitWidgets_QtGui[15].it_td

#define sipType_QPixmap sipImportedTypes_QtWebKitWidgets_QtGui[23].it_td

#define sipType_QMouseEvent sipImportedTypes_QtWebKitWidgets_QtGui[12].it_td

#define sipType_QWheelEvent sipImportedTypes_QtWebKitWidgets_QtGui[28].it_td

#define sipType_QTabletEvent sipImportedTypes_QtWebKitWidgets_QtGui[27].it_td

#define sipType_QKeyEvent sipImportedTypes_QtWebKitWidgets_QtGui[11].it_td

#define sipType_QFocusEvent sipImportedTypes_QtWebKitWidgets_QtGui[7].it_td

#define sipType_QPaintEvent sipImportedTypes_QtWebKitWidgets_QtGui[17].it_td

#define sipType_QMoveEvent sipImportedTypes_QtWebKitWidgets_QtGui[13].it_td

#define sipType_QResizeEvent sipImportedTypes_QtWebKitWidgets_QtGui[25].it_td

#define sipType_QCloseEvent sipImportedTypes_QtWebKitWidgets_QtGui[1].it_td

#define sipType_QShowEvent sipImportedTypes_QtWebKitWidgets_QtGui[26].it_td

#define sipType_QHideEvent sipImportedTypes_QtWebKitWidgets_QtGui[8].it_td

#define sipType_QContextMenuEvent sipImportedTypes_QtWebKitWidgets_QtGui[2].it_td

#define sipType_QInputMethodEvent sipImportedTypes_QtWebKitWidgets_QtGui[10].it_td

#define sipType_QDropEvent sipImportedTypes_QtWebKitWidgets_QtGui[6].it_td

#define sipType_QDragMoveEvent sipImportedTypes_QtWebKitWidgets_QtGui[5].it_td

#define sipType_QDragEnterEvent sipImportedTypes_QtWebKitWidgets_QtGui[3].it_td

#define sipType_QDragLeaveEvent sipImportedTypes_QtWebKitWidgets_QtGui[4].it_td

#define sipType_QActionEvent sipImportedTypes_QtWebKitWidgets_QtGui[0].it_td

#define sipType_QIcon sipImportedTypes_QtWebKitWidgets_QtGui[9].it_td

#define sipType_QPainter sipImportedTypes_QtWebKitWidgets_QtGui[18].it_td

#define sipType_QPainter_RenderHint sipImportedTypes_QtWebKitWidgets_QtGui[19].it_td

#define sipType_QPainter_RenderHints sipImportedTypes_QtWebKitWidgets_QtGui[20].it_td

#define sipType_QPaintEngine sipImportedTypes_QtWebKitWidgets_QtGui[16].it_td

#define sipType_QPainterPath sipImportedTypes_QtWebKitWidgets_QtGui[21].it_td

#define sipType_QPalette sipImportedTypes_QtWebKitWidgets_QtGui[22].it_td

#define sipType_QRegion sipImportedTypes_QtWebKitWidgets_QtGui[24].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtGui[];

#define sipType_QWidget sipImportedTypes_QtWebKitWidgets_QtWidgets[17].it_td

#define sipType_QAction sipImportedTypes_QtWebKitWidgets_QtWidgets[0].it_td

#define sipType_QGraphicsLayoutItem sipImportedTypes_QtWebKitWidgets_QtWidgets[3].it_td

#define sipType_QGraphicsItem sipImportedTypes_QtWebKitWidgets_QtWidgets[1].it_td

#define sipType_QGraphicsItem_GraphicsItemChange sipImportedTypes_QtWebKitWidgets_QtWidgets[2].it_td

#define sipType_QGraphicsObject sipImportedTypes_QtWebKitWidgets_QtWidgets[4].it_td

#define sipType_QGraphicsWidget sipImportedTypes_QtWebKitWidgets_QtWidgets[12].it_td

#define sipType_QGraphicsSceneMouseEvent sipImportedTypes_QtWebKitWidgets_QtWidgets[8].it_td

#define sipType_QGraphicsSceneWheelEvent sipImportedTypes_QtWebKitWidgets_QtWidgets[11].it_td

#define sipType_QGraphicsSceneContextMenuEvent sipImportedTypes_QtWebKitWidgets_QtWidgets[5].it_td

#define sipType_QGraphicsSceneHoverEvent sipImportedTypes_QtWebKitWidgets_QtWidgets[7].it_td

#define sipType_QGraphicsSceneDragDropEvent sipImportedTypes_QtWebKitWidgets_QtWidgets[6].it_td

#define sipType_QGraphicsSceneResizeEvent sipImportedTypes_QtWebKitWidgets_QtWidgets[10].it_td

#define sipType_QGraphicsSceneMoveEvent sipImportedTypes_QtWebKitWidgets_QtWidgets[9].it_td

#define sipType_QMenu sipImportedTypes_QtWebKitWidgets_QtWidgets[13].it_td

#define sipType_QStyleOption sipImportedTypes_QtWebKitWidgets_QtWidgets[14].it_td

#define sipType_QStyleOptionGraphicsItem sipImportedTypes_QtWebKitWidgets_QtWidgets[15].it_td

#define sipType_QUndoStack sipImportedTypes_QtWebKitWidgets_QtWidgets[16].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtWidgets[];

#define sipType_QPrinter sipImportedTypes_QtWebKitWidgets_QtPrintSupport[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtPrintSupport[];

#define sipType_QWebElement sipImportedTypes_QtWebKitWidgets_QtWebKit[0].it_td

#define sipType_QWebElementCollection sipImportedTypes_QtWebKitWidgets_QtWebKit[1].it_td

#define sipType_QWebHistoryItem sipImportedTypes_QtWebKitWidgets_QtWebKit[3].it_td

#define sipType_QWebHistory sipImportedTypes_QtWebKitWidgets_QtWebKit[2].it_td

#define sipType_QWebPluginFactory sipImportedTypes_QtWebKitWidgets_QtWebKit[4].it_td

#define sipType_QWebSecurityOrigin sipImportedTypes_QtWebKitWidgets_QtWebKit[5].it_td

#define sipType_QWebSettings sipImportedTypes_QtWebKitWidgets_QtWebKit[6].it_td
extern sipImportedTypeDef sipImportedTypes_QtWebKitWidgets_QtWebKit[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtWebKitWidgets_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtWebKitWidgets_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtWebKitWidgets_qt_metacast;

#endif
